﻿using System;
using System.ComponentModel;
using Wisej.Web;

namespace Wisej.DGVSyncSample
{
	public class DataGridViewWithTopRows : DataGridView
	{
		private DataGridView childGrid;

		public DataGridViewWithTopRows()
		{
			InitializeComponent();
		}

		[Browsable(false)]
		public DataGridView HeaderGrid
		{
			get { return this.childGrid;  }
		}

		protected override void OnColumnAdded(DataGridViewColumnEventArgs e)
		{
			var col = (DataGridViewColumn)e.Column.Clone();
			col.Frozen = e.Column.Frozen;
			col.HeaderText = e.Column.HeaderText;

			this.childGrid.Columns.Add(col);

			base.OnColumnAdded(e);
		}

		protected override void OnColumnWidthChanged(DataGridViewColumnEventArgs e)
		{
			this.childGrid.Columns[e.Column.Index].Width = e.Column.Width;

			base.OnColumnWidthChanged(e);
		}

		protected override void OnColumnStateChanged(DataGridViewColumnStateChangedEventArgs e)
		{
			if (e.StateChanged.HasFlag(DataGridViewElementStates.Frozen))
				this.childGrid.Columns[e.Column.Index].Frozen = e.Column.Frozen;

			base.OnColumnStateChanged(e);
		}

		protected override void OnColumnDisplayIndexChanged(DataGridViewColumnEventArgs e)
		{
			this.childGrid.Columns[e.Column.Index].DisplayIndex = e.Column.DisplayIndex;

			base.OnColumnDisplayIndexChanged(e);
		}

		protected override void OnColumnRemoved(DataGridViewColumnEventArgs e)
		{
			if (!this.childGrid.IsDisposed)
				this.childGrid.Columns.RemoveAt(e.Column.Index);

			base.OnColumnRemoved(e);
		}

		protected override void OnCellValueChanged(DataGridViewCellEventArgs e)
		{
			if (e.RowIndex == -1)
				this.childGrid.Columns[e.ColumnIndex].HeaderText = this.Columns[e.ColumnIndex].HeaderText;

			base.OnCellValueChanged(e);
		}

		private void InitializeComponent()
		{
			this.childGrid = new Wisej.Web.DataGridView();
			((System.ComponentModel.ISupportInitialize)(this.childGrid)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this)).BeginInit();
			this.SuspendLayout();
			// 
			// childGrid
			// 
			this.childGrid.BorderStyle = Wisej.Web.BorderStyle.None;
			this.childGrid.CssStyle = "border-bottom: 2px solid #BDBFBF";
			this.childGrid.Dock = Wisej.Web.DockStyle.Top;
			this.childGrid.Location = new System.Drawing.Point(0, 0);
			this.childGrid.Name = "childGrid";
			this.childGrid.ResizableEdges = Wisej.Web.AnchorStyles.Bottom;
			this.childGrid.ScrollBars = Wisej.Web.ScrollBars.None;
			this.childGrid.Size = new System.Drawing.Size(555, 67);
			this.childGrid.TabIndex = 0;
			// 
			// DataGridViewWithTopRows
			// 
			this.ColumnHeadersVisible = false;
			this.Controls.Add(this.childGrid);
			this.InitScript = "this.bindToGrid(this.childGrid, true);";
			this.Name = "DataGridViewWithTopRows";
			this.Size = new System.Drawing.Size(557, 434);
			((System.ComponentModel.ISupportInitialize)(this.childGrid)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this)).EndInit();
			this.ResumeLayout(false);

		}
	}
}